## Example Exam

### Supervision List for A101.

University of Example
Department of Example
Bachelor of Example
Exam: | Example Exam Winter Semester 2023/2024
Examiner 1: | Prof. Dr. John Doe
Examiner 2: | Prof. Dr. Jane Doe
Date: | 01.01.2024

Name | First Name | Room / Seat | Signature | Info
--- | --- | --- | --- | ---
Doe | John | A101 / 1 |  |
Doe | Jane | A101 / 2 |  |

| Place, Date, Signature of Supervisor

#### Space for notes

Doe John Example Exam A101 1

## Hand In

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | John Doe

Login Info

Username: |  | johndoe
Password: |  | password

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |
Signature: |  |
|  | John Doe

## Take Home

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | John Doe

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |

#### Space for notes

Doe Jane Example Exam A101 2

## Hand In

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | Jane Doe

Login Info

Username: |  | janedoe
Password: |  | password

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |
Signature: |  |
|  | Jane Doe

## Take Home

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | Jane Doe

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |

#### Space for notes

Student Backup Example Exam A101 3

## Hand In

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | Backup Student

Login Info

Username: |  | backupstudent
Password: |  | password

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |
Signature: |  |
|  | Backup Student

## Take Home

### Example Exam

Room: | A101 |  | Date: | 01.01.2024
Name: | Backup Student

#### Fill In When Handing In

Hashcode: |  |  |  |  |  | - |  |  |  |  | - |  |  |  |